==> bear_2.5.5.tar.gz: bear/R/description_TTT.r <==
description_TTT<-function(){
cat("\n\n")
cat("*****************************************************************************\n")
cat("                      Two-Times-Tmax (TTT) method                            \n")
cat("-----------------------------------------------------------------------------\n")
cat(" The TTT method is based on the Bateman function.  The Bateman function      \n")
cat(" has two outstanding points.  First, the maximum of the curve (Cmax at       \n")
cat(" Tmax) and secondly, the inflection point of the curve (Cinpt at Tinpt).     \n")
cat(" The inflection point of the curve describes the point where the algebraic   \n")
cat(" sign of the curvature changes. Tinpt is equal to two times Tmax.  Thus,     \n")
cat(" The twofold of the observed Tmax value can be used as a threshold of time   \n")
cat(" points to be included in the calculation of lambda_z.                     \n\n")
cat(" Please note: TTT is only for when one (or more) curve(s) have # of data     \n")
cat(" points > 2 after 2*Tmax; otherwise, it will cause error. bear will be       \n")
cat(" crashed in this case. If so, please try another method next time.         \n\n")
cat(" ref.: Scheerans C, Derendorf H and C Kloft. Proposal for a Standardised     \n")
cat(" Identification of the Mono-Exponential Terminal Phase for Orally            \n")
cat(" Administered Drugs. Biopharm Drug Dispos 29, 145-157 (2008).                \n")
cat("*****************************************************************************\n")
cat("\n")
alarm(); alarm()
readline(" Press Enter to continue...")
}

==> bear_2.5.6.tar.gz: bear/R/description_TTT.r <==
description_TTT<-function(){
cat("\n\n")
cat("*****************************************************************************\n")
cat("                      Two-Times-Tmax (TTT) method                            \n")
cat("-----------------------------------------------------------------------------\n")
cat(" The TTT method is based on the Bateman function.  The Bateman function      \n")
cat(" has two outstanding points.  First, the maximum of the curve (Cmax at       \n")
cat(" Tmax) and secondly, the inflection point of the curve (Cinpt at Tinpt).     \n")
cat(" The inflection point of the curve describes the point where the algebraic   \n")
cat(" sign of the curvature changes. Tinpt is equal to 2*Tmax. Thus, the twofold  \n")
cat(" of the observed Tmax value can be used as a threshold of time points to be  \n")
cat(" included in the calculation of lambda_z.                                  \n\n")
cat(" Please note: TTT is only for when one (or more) curve(s) have # of data     \n")
cat(" points > 2 after 2*Tmax; otherwise, it will cause error. bear may be        \n")
cat(" crashed in this case. If so, please try other method next time.           \n\n")
cat(" ref.: Scheerans C, Derendorf H and C Kloft. Proposal for a Standardised     \n")
cat(" Identification of the Mono-Exponential Terminal Phase for Orally            \n")
cat(" Administered Drugs. Biopharm Drug Dispos 29, 145-157 (2008).                \n")
cat("*****************************************************************************\n")
cat("\n")
alarm(); alarm()
readline(" Press Enter to continue...")
}
